@@ -51,12 +51,12 @@ CommandKeyRange ParseStreamReadRange(const std::vector<std::string> &args, uint3
 }
 }  // namespace
 
-void AddStreamEntriesToResponse(const Connection *conn, std::string *output, const std::vector<StreamEntry> &entries) {
+void AddStreamEntriesToResponse(std::string *output, const std::vector<StreamEntry> &entries) {
   output->append(redis::MultiLen(entries.size()));
   for (const auto &entry : entries) {
     output->append(redis::MultiLen(2));
     output->append(redis::BulkString(entry.key));
-    output->append(conn->MultiBulkString(entry.values));
+    output->append(redis::ArrayOfBulkStrings(entry.values));
   }
 }
 
@@ -359,7 +359,7 @@ class CommandXClaim : public Commander {
     }
 
     if (!stream_claim_options_.just_id) {
-      AddStreamEntriesToResponse(conn, output, result.entries);
+      AddStreamEntriesToResponse(output, result.entries);
     } else {
       output->append(redis::MultiLen(result.ids.size()));
       for (const auto &id : result.ids) {
@@ -454,7 +454,7 @@ class CommandAutoClaim : public Commander {
         output->append(redis::BulkString(item.key));
       }
     } else {
-      AddStreamEntriesToResponse(conn, output, result.entries);
+      AddStreamEntriesToResponse(output, result.entries);
     }
 
     output->append(redis::MultiLen(result.deleted_ids.size()));
@@ -766,7 +766,7 @@ class CommandXInfo : public Commander {
       }
     } else {
       output->append(redis::BulkString("entries"));
-      AddStreamEntriesToResponse(conn, output, info.entries);
+      AddStreamEntriesToResponse(output, info.entries);
     }
 
     return Status::OK();
@@ -1024,7 +1024,7 @@ class CommandXRange : public Commander {
       return {Status::RedisExecErr, s.ToString()};
     }
 
-    AddStreamEntriesToResponse(conn, output, result);
+    AddStreamEntriesToResponse(output, result);
 
     return Status::OK();
   }
@@ -1112,7 +1112,7 @@ class CommandXRevRange : public Commander {
       return {Status::RedisExecErr, s.ToString()};
     }
 
-    AddStreamEntriesToResponse(conn, output, result);
+    AddStreamEntriesToResponse(output, result);
 
     return Status::OK();
   }
@@ -1255,17 +1255,17 @@ class CommandXRead : public Commander,
       return Status::OK();
     }
 
-    return SendResults(conn, output, results);
+    return SendResults(output, results);
   }
 
-  static Status SendResults(Connection *conn, std::string *output, const std::vector<StreamReadResult> &results) {
+  static Status SendResults(std::string *output, const std::vector<StreamReadResult> &results) {
     output->append(redis::MultiLen(results.size()));
 
     for (const auto &result : results) {
       output->append(redis::MultiLen(2));
       output->append(redis::BulkString(result.name));
 
-      AddStreamEntriesToResponse(conn, output, result.entries);
+      AddStreamEntriesToResponse(output, result.entries);
     }
 
     return Status::OK();
@@ -1366,7 +1366,7 @@ class CommandXRead : public Commander,
       output.append(redis::MultiLen(2));
       output.append(redis::BulkString(result.name));
 
-      AddStreamEntriesToResponse(conn_, &output, result.entries);
+      AddStreamEntriesToResponse(&output, result.entries);
     }
 
     conn_->Reply(output);
@@ -1676,7 +1676,7 @@ class CommandXReadGroup : public Commander,
     for (const auto &result : results) {
       output.append(redis::MultiLen(2));
       output.append(redis::BulkString(result.name));
-      AddStreamEntriesToResponse(conn_, &output, result.entries);
+      AddStreamEntriesToResponse(&output, result.entries);
     }
 
     conn_->Reply(output);
