@@ -546,6 +546,13 @@ void Worker::KillClient(redis::Connection *self, uint64_t id, const std::string
   }
 }
 
+void Worker::LuaReset() {
+  auto lua = lua_.exchange(lua::CreateState());
+  lua::DestroyState(lua);
+}
+
+int64_t Worker::GetLuaMemorySize() { return (int64_t)lua_gc(lua_, LUA_GCCOUNT, 0) * 1024; }
+
 void Worker::KickoutIdleClients(int timeout) {
   std::vector<std::pair<int, uint64_t>> to_be_killed_conns;
 
