@@ -37,54 +37,62 @@ class Stream : public SubKeyScanner {
  public:
   explicit Stream(engine::Storage *storage, const std::string &ns)
       : SubKeyScanner(storage, ns), stream_cf_handle_(storage->GetCFHandle(ColumnFamilyID::Stream)) {}
-  rocksdb::Status Add(const Slice &stream_name, const StreamAddOptions &options, const std::vector<std::string> &values,
-                      StreamEntryID *id);
-  rocksdb::Status CreateGroup(const Slice &stream_name, const StreamXGroupCreateOptions &options,
+  rocksdb::Status Add(engine::Context &ctx, const Slice &stream_name, const StreamAddOptions &options,
+                      const std::vector<std::string> &values, StreamEntryID *id);
+  rocksdb::Status CreateGroup(engine::Context &ctx, const Slice &stream_name, const StreamXGroupCreateOptions &options,
                               const std::string &group_name);
-  rocksdb::Status DestroyGroup(const Slice &stream_name, const std::string &group_name, uint64_t *delete_cnt);
-  rocksdb::Status CreateConsumer(const Slice &stream_name, const std::string &group_name,
+  rocksdb::Status DestroyGroup(engine::Context &ctx, const Slice &stream_name, const std::string &group_name,
+                               uint64_t *delete_cnt);
+  rocksdb::Status CreateConsumer(engine::Context &ctx, const Slice &stream_name, const std::string &group_name,
                                  const std::string &consumer_name, int *created_number);
-  rocksdb::Status DestroyConsumer(const Slice &stream_name, const std::string &group_name,
+  rocksdb::Status DestroyConsumer(engine::Context &ctx, const Slice &stream_name, const std::string &group_name,
                                   const std::string &consumer_name, uint64_t &deleted_pel);
-  rocksdb::Status GroupSetId(const Slice &stream_name, const std::string &group_name,
+  rocksdb::Status GroupSetId(engine::Context &ctx, const Slice &stream_name, const std::string &group_name,
                              const StreamXGroupCreateOptions &options);
-  rocksdb::Status DeleteEntries(const Slice &stream_name, const std::vector<StreamEntryID> &ids, uint64_t *deleted_cnt);
-  rocksdb::Status DeletePelEntries(const Slice &stream_name, const std::string &group_name,
+  rocksdb::Status DeleteEntries(engine::Context &ctx, const Slice &stream_name, const std::vector<StreamEntryID> &ids,
+                                uint64_t *deleted_cnt);
+  rocksdb::Status DeletePelEntries(engine::Context &ctx, const Slice &stream_name, const std::string &group_name,
                                    const std::vector<StreamEntryID> &entry_ids, uint64_t *acknowledged);
-  rocksdb::Status ClaimPelEntries(const Slice &stream_name, const std::string &group_name,
+  rocksdb::Status ClaimPelEntries(engine::Context &ctx, const Slice &stream_name, const std::string &group_name,
                                   const std::string &consumer_name, uint64_t min_idle_time_ms,
                                   const std::vector<StreamEntryID> &entry_ids, const StreamClaimOptions &options,
                                   StreamClaimResult *result);
-  rocksdb::Status AutoClaim(const Slice &stream_name, const std::string &group_name, const std::string &consumer_name,
-                            const StreamAutoClaimOptions &options, StreamAutoClaimResult *result);
-  rocksdb::Status Len(const Slice &stream_name, const StreamLenOptions &options, uint64_t *size);
-  rocksdb::Status GetStreamInfo(const Slice &stream_name, bool full, uint64_t count, StreamInfo *info);
-  rocksdb::Status GetGroupInfo(const Slice &stream_name,
+  rocksdb::Status AutoClaim(engine::Context &ctx, const Slice &stream_name, const std::string &group_name,
+                            const std::string &consumer_name, const StreamAutoClaimOptions &options,
+                            StreamAutoClaimResult *result);
+  rocksdb::Status Len(engine::Context &ctx, const Slice &stream_name, const StreamLenOptions &options, uint64_t *size);
+  rocksdb::Status GetStreamInfo(engine::Context &ctx, const Slice &stream_name, bool full, uint64_t count,
+                                StreamInfo *info);
+  rocksdb::Status GetGroupInfo(engine::Context &ctx, const Slice &stream_name,
                                std::vector<std::pair<std::string, StreamConsumerGroupMetadata>> &group_metadata);
-  rocksdb::Status GetConsumerInfo(const Slice &stream_name, const std::string &group_name,
+  rocksdb::Status GetConsumerInfo(engine::Context &ctx, const Slice &stream_name, const std::string &group_name,
                                   std::vector<std::pair<std::string, StreamConsumerMetadata>> &consumer_metadata);
-  rocksdb::Status Range(const Slice &stream_name, const StreamRangeOptions &options, std::vector<StreamEntry> *entries);
-  rocksdb::Status RangeWithPending(const Slice &stream_name, StreamRangeOptions &options,
+  rocksdb::Status GetPendingEntries(engine::Context &ctx, StreamPendingOptions &options,
+                                    StreamGetPendingEntryResult &pending_infos, std::vector<StreamNACK> &ext_results);
+  rocksdb::Status Range(engine::Context &ctx, const Slice &stream_name, const StreamRangeOptions &options,
+                        std::vector<StreamEntry> *entries);
+  rocksdb::Status RangeWithPending(engine::Context &ctx, const Slice &stream_name, StreamRangeOptions &options,
                                    std::vector<StreamEntry> *entries, std::string &group_name,
                                    std::string &consumer_name, bool noack, bool latest);
-  rocksdb::Status Trim(const Slice &stream_name, const StreamTrimOptions &options, uint64_t *delete_cnt);
-  rocksdb::Status GetMetadata(Database::GetOptions get_options, const Slice &stream_name, StreamMetadata *metadata);
-  rocksdb::Status GetLastGeneratedID(const Slice &stream_name, StreamEntryID *id);
-  rocksdb::Status SetId(const Slice &stream_name, const StreamEntryID &last_generated_id,
+  rocksdb::Status Trim(engine::Context &ctx, const Slice &stream_name, const StreamTrimOptions &options,
+                       uint64_t *delete_cnt);
+  rocksdb::Status GetMetadata(engine::Context &ctx, const Slice &stream_name, StreamMetadata *metadata);
+  rocksdb::Status GetLastGeneratedID(engine::Context &ctx, const Slice &stream_name, StreamEntryID *id);
+  rocksdb::Status SetId(engine::Context &ctx, const Slice &stream_name, const StreamEntryID &last_generated_id,
                         std::optional<uint64_t> entries_added, std::optional<StreamEntryID> max_deleted_id);
 
  private:
   rocksdb::ColumnFamilyHandle *stream_cf_handle_;
 
-  rocksdb::Status range(const std::string &ns_key, const StreamMetadata &metadata, const StreamRangeOptions &options,
-                        std::vector<StreamEntry> *entries) const;
-  rocksdb::Status getEntryRawValue(const std::string &ns_key, const StreamMetadata &metadata, const StreamEntryID &id,
-                                   std::string *value) const;
+  rocksdb::Status range(engine::Context &ctx, const std::string &ns_key, const StreamMetadata &metadata,
+                        const StreamRangeOptions &options, std::vector<StreamEntry> *entries) const;
+  rocksdb::Status getEntryRawValue(engine::Context &ctx, const std::string &ns_key, const StreamMetadata &metadata,
+                                   const StreamEntryID &id, std::string *value) const;
   StreamEntryID entryIDFromInternalKey(const rocksdb::Slice &key) const;
   std::string internalKeyFromEntryID(const std::string &ns_key, const StreamMetadata &metadata,
                                      const StreamEntryID &id) const;
-  uint64_t trim(const std::string &ns_key, const StreamTrimOptions &options, StreamMetadata *metadata,
-                rocksdb::WriteBatch *batch);
+  rocksdb::Status trim(engine::Context &ctx, const std::string &ns_key, const StreamTrimOptions &options,
+                       StreamMetadata *metadata, rocksdb::WriteBatch *batch, uint64_t &delete_cnt);
   std::string internalKeyFromGroupName(const std::string &ns_key, const StreamMetadata &metadata,
                                        const std::string &group_name) const;
   std::string groupNameFromInternalKey(rocksdb::Slice key) const;
@@ -95,8 +103,9 @@ class Stream : public SubKeyScanner {
   std::string consumerNameFromInternalKey(rocksdb::Slice key) const;
   static std::string encodeStreamConsumerMetadataValue(const StreamConsumerMetadata &consumer_metadata);
   static StreamConsumerMetadata decodeStreamConsumerMetadataValue(const std::string &value);
-  rocksdb::Status createConsumerWithoutLock(const Slice &stream_name, const std::string &group_name,
-                                            const std::string &consumer_name, int *created_number);
+  rocksdb::Status createConsumerWithoutLock(engine::Context &ctx, const Slice &stream_name,
+                                            const std::string &group_name, const std::string &consumer_name,
+                                            int *created_number);
   std::string internalPelKeyFromGroupAndEntryId(const std::string &ns_key, const StreamMetadata &metadata,
                                                 const std::string &group_name, const StreamEntryID &id);
   StreamEntryID groupAndEntryIdFromPelInternalKey(rocksdb::Slice key, std::string &group_name);
