@@ -500,6 +500,23 @@ func testString(t *testing.T, configs util.KvrocksServerConfigs) {
 		require.ErrorContains(t, rdb.SetRange(ctx, "mykey", 0, "bar").Err(), "WRONGTYPE")
 	})
 
+	t.Run("SETRANGE with negative offset", func(t *testing.T) {
+		require.ErrorContains(t, rdb.SetRange(ctx, "setrange_negative_offset", -1, "bar").Err(),
+			"value is not an integer or out of range")
+		require.ErrorContains(t, rdb.SetRange(ctx, "setrange_negative_offset", -2147483599, "bar").Err(),
+			"value is not an integer or out of range")
+	})
+
+	t.Run("SETRANGE with offset + value length too large", func(t *testing.T) {
+		protoMaxBulkLen := int64(1024 * 1024)
+		require.NoError(t, rdb.ConfigSet(ctx, "proto-max-bulk-len", strconv.FormatInt(protoMaxBulkLen, 10)).Err())
+		require.ErrorContains(t, rdb.SetRange(ctx, "setrange_out_of_range", protoMaxBulkLen, "world").Err(),
+			"string exceeds maximum allowed size")
+
+		// it should be able to set the value if the length is protoMaxBulkLen
+		require.NoError(t, rdb.SetRange(ctx, "setrange_out_of_range", protoMaxBulkLen-5, "world").Err())
+	})
+
 	t.Run("GETRANGE against non-existing key", func(t *testing.T) {
 		require.NoError(t, rdb.Del(ctx, "mykey").Err())
 		require.EqualValues(t, "", rdb.GetRange(ctx, "mykey", 0, -1).Val())
