@@ -46,7 +46,7 @@ struct Options {
   std::string conf_file = kDefaultConfPath;
 };
 
-extern "C" void SignalHandler(int sig) {
+extern "C" void SignalHandler([[maybe_unused]] int sig) {
   if (hup_handler) hup_handler();
 }
 
